"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process = require("child_process");
function emulatorCmd(args) {
    if (args) {
        return `${process.env.ANDROID_HOME}/emulator/emulator ${args}`;
    }
    return `${process.env.ANDROID_HOME}/emulator/emulator`;
}
function serializeLaunchOptions(options) {
    const serializedOptions = [];
    if (options === null || options === void 0 ? void 0 : options.noSnapshotLoad) {
        serializedOptions.push('-no-snapshot-load');
    }
    return serializedOptions;
}
function parseListAVDs(stdout) {
    return stdout.trim().split('\n');
}
class AVDManager {
    async getAll() {
        return new Promise((resolve, reject) => {
            child_process.exec(emulatorCmd('-list-avds'), (error, stdout, stderr) => {
                if (error) {
                    reject(error);
                    return;
                }
                if (stderr) {
                    reject(stderr);
                    return;
                }
                resolve(parseListAVDs(stdout));
            });
        });
    }
    launch(name, options) {
        const args = ['-avd', name].concat(serializeLaunchOptions(options));
        child_process
            .spawn(emulatorCmd(), args, { detached: true, stdio: 'ignore' })
            .unref();
    }
}
exports.default = AVDManager;
