"use strict";
const command_1 = require("@oclif/command");
const avdmanager_1 = require("./avdmanager");
const inquirer = require("inquirer");
function getRandomAVDs(avds) {
    const randomIndex = Math.floor(Math.random() * avds.length);
    return [avds[randomIndex]];
}
async function getUserSelectedAVDs(avds) {
    const answer = await inquirer.prompt([selectDevicesQuestion(avds)]);
    return answer.avds;
}
function createLaunchOptions(flags) {
    return {
        noSnapshotLoad: flags.cold,
    };
}
function selectDevicesQuestion(avds) {
    return {
        type: 'checkbox',
        name: 'avds',
        message: 'Select a device',
        choices: avds,
    };
}
class AvdLauncher extends command_1.Command {
    async run() {
        // Handle built-in flags
        const { flags } = this.parse(AvdLauncher);
        const avdManager = new avdmanager_1.default();
        const availableAvds = await avdManager.getAll();
        let avdsToLaunch;
        if (flags.random) {
            avdsToLaunch = getRandomAVDs(availableAvds);
        }
        else {
            avdsToLaunch = await getUserSelectedAVDs(availableAvds);
        }
        avdsToLaunch.forEach(avd => {
            process.stdout.write(`Launching ${avd}...`);
            avdManager.launch(avd, createLaunchOptions(flags));
            process.stdout.write('done.\n');
        });
    }
}
AvdLauncher.description = 'Launch an Android Virtual Device.';
AvdLauncher.flags = {
    cold: command_1.flags.boolean({ char: 'c', description: 'Performs a cold boot and saves the emulator state on exit.' }),
    random: command_1.flags.boolean({ char: 'r', description: 'Launches a random AVD.' }),
    version: command_1.flags.version({ char: 'v' }),
    help: command_1.flags.help({ char: 'h' }),
};
module.exports = AvdLauncher;
